@@ -1,3 +1,4 @@
+import random
 from pathlib import Path
 
 from ._main import (
@@ -41,6 +42,11 @@ def replace_redirects(args):
 
     urls = find_urls(files)
 
+    # Shuffle the urls. In case there's rate limiting (e.g., on github.com),
+    # different URLs are checked on every turn.
+    urls = list(urls)
+    random.shuffle(urls)
+
     urls_str = plural(len(urls), "unique URL")
     files_str = plural(len(files), "file")
     ifiles_str = plural(num_ignored_files, "file")
